@@ -11,7 +11,7 @@ import logging
 class Handler(logging.StreamHandler):
 
     def emit(self, record):
-        raise RuntimeError, str(record)
+        raise RuntimeError(str(record))
 
 handler = Handler()
 logger = logging.getLogger('pyutilib.workflow')
@@ -30,7 +30,7 @@ class TestData(unittest.TestCase):
         data.aa = 'here is more'
         data.clean()
         pyutilib.misc.setup_redirect(currdir+'test1.out')
-        print data
+        print(data)
         pyutilib.misc.reset_redirect()
         self.assertFileEqualsBaseline(currdir+'test1.out', currdir+'test1.txt')
         self.assertEquals(len(data._dirty_), 0)
@@ -46,7 +46,7 @@ class TestData(unittest.TestCase):
         data['aa'] = 'here is more'
         data.clean()
         pyutilib.misc.setup_redirect(currdir+'test2.out')
-        print repr(data)
+        print(repr(data))
         pyutilib.misc.reset_redirect()
         self.assertFileEqualsBaseline(currdir+'test2.out', currdir+'test2.txt')
         self.assertEquals(len(data._dirty_), 0)
