@@ -15,11 +15,11 @@
 
 __all__ = ['Workflow']
 
-from task import Task, EmptyTask, NoTask
 import argparse
-from pyutilib.misc import Options
 import pprint
 from collections import deque
+from pyutilib.workflow.task import Task, EmptyTask, NoTask
+from pyutilib.misc import Options
 
 try:
     from collections import OrderedDict
@@ -39,7 +39,6 @@ def _collect_parser_groups(t):
 
 def _set_arguments(t):
     for arg in t._parser_arg:
-        #print 'x',arg
         args = arg[0]
         kwargs = arg[1]
         try:
@@ -60,7 +59,7 @@ class Workflow(Task):
 
     def add(self, task, loadall=True):
         if self.debug:
-            print "ADDING",task.id          #pragma:nocover
+            print("ADDING",task.id)          #pragma:nocover
         if task.id == NoTask.id:
             return
         if task.id in self._tasks:
@@ -68,12 +67,9 @@ class Workflow(Task):
         self._tasks[task.id] = task
         if not loadall:
             return
-        #print 'xx',task.inputs.keys()
         for name in task.inputs:
             for t in task.inputs[name].from_tasks():
                 self.add(t)
-            ##t = task.inputs[name].from_task()
-            #print "x",name,t.id
             
             if len(task.inputs[name].from_tasks()) > 0:
                 continue
@@ -84,7 +80,6 @@ class Workflow(Task):
                 #
                 if not name in self._start_task.outputs:
                     self._start_task.outputs.declare(name)
-                    #print "Declaring input "+name
                     self.inputs.declare(name, optional=True)
                 # TODO: this is a bit of a hack...
                 val = getattr(task.inputs,name).get_value()
@@ -94,12 +89,6 @@ class Workflow(Task):
                     # TBD: when do we get this exception?
                     pass
                 getattr(self.inputs,name).set_value(val)
-            #getattr(self._start_task.outputs,name).set_value(val)
-            #print "Z",task.inputs
-            #print "Z",self._start_task.outputs[name].from_task.id
-            #print "Z",self._start_task.outputs[name].to_task.id
-            #print "ZZZ",self._start_task.outputs
-        #print 'xx',task.inputs.keys()
         for name in task.output_controls:
             for c in task.output_controls[name].output_connections:
                 self.add(c.to_port.task)
@@ -110,7 +99,7 @@ class Workflow(Task):
                     self.add(c.to_port.task)
             else:
                 if name in self._final_task.inputs:
-                    raise ValueError, "Cannot declare a workplan with multiple output values that share the same name: %s" % name
+                    raise ValueError("Cannot declare a workplan with multiple output values that share the same name: %s" % name)
                 self.outputs.declare(name)
                 self._final_task.inputs.declare(name)
                 setattr(self._final_task.inputs, name, task.outputs[name])
@@ -118,7 +107,6 @@ class Workflow(Task):
     def _call_init(self, *options, **kwds):
         Task._call_init(self, *options, **kwds)
         for i in self.inputs:
-            #print "_call_init",self.name,i, self.inputs[i].get_value()
             val = self.inputs[i].get_value()
             if not val is None:
                 self._start_task.outputs[i].set_value( val )
@@ -163,11 +151,11 @@ class Workflow(Task):
     def execute(self):
         #return self._dfs_([self._start_task.id], lambda t: t.__call__())
         if self.debug:                              #pragma:nocover
-            print self.name, '---------------'
-            print self.name, '---------------'
-            print self.name, '   STARTING'
-            print self.name, '---------------'
-            print self.name, '---------------'
+            print( self.name, '---------------')
+            print( self.name, '---------------')
+            print( self.name, '   STARTING')
+            print( self.name, '---------------')
+            print( self.name, '---------------')
         #
         queued = set([self._start_task.id])
         queue = deque([self._start_task])
@@ -178,9 +166,8 @@ class Workflow(Task):
                 if not t.id in queued and t.ready():
                     #
                     if self.debug:                  #pragma:nocover
-                        print self.name, "WAITING: ",t.id," not queued and task ready"
-                        print self.name, "Waiting task",t.name,t.id,t.ready()
-                        #print self.name, "HERE",t,repr(t)
+                        print(self.name, "WAITING: ",t.id," not queued and task ready")
+                        print(self.name, "Waiting task",t.name,t.id,t.ready())
                     #
                     queue.append(t)
                     queued.add(t.id)
@@ -195,10 +182,10 @@ class Workflow(Task):
             task = queue.popleft()
             #
             if self.debug:                          #pragma:nocover
-                print self.name, "TASK   ",str(task)
-                print self.name, "QUEUE  ",queued
-                print self.name, "WAITING",waiting.keys()
-                print self.name, "Executing Task "+task.name,task.next_task_ids()
+                print(self.name, "TASK   ",str(task))
+                print(self.name, "QUEUE  ",queued)
+                print(self.name, "WAITING",waiting.keys())
+                print(self.name, "Executing Task "+task.name,task.next_task_ids())
             #
             queued.remove(task.id)
             task()
@@ -208,9 +195,8 @@ class Workflow(Task):
                 if t.ready():
                     #
                     if self.debug:                  #pragma:nocover
-                        print self.name, "NEXT: ",t.id," not queued and task ready"
-                        print self.name, "Scheduling task",t.name,t.id,t.ready()
-                        #print self.name, "HERE",t,repr(t)
+                        print(self.name, "NEXT: ",t.id," not queued and task ready")
+                        print(self.name, "Scheduling task",t.name,t.id,t.ready())
                     #
                     queue.append(t)
                     queued.add(t.id)
@@ -221,17 +207,16 @@ class Workflow(Task):
                         waiting[t.id] = t
                     #
                     if self.debug:                  #pragma:nocover
-                        print self.name, "NEXT: ",t.id," not queued and task NOT ready"
-                        print self.name, "Ignoring task",t.name, t.id,t.ready()
-                        #print self.name, "HERE",t,repr(t)
+                        print(self.name, "NEXT: ",t.id," not queued and task NOT ready")
+                        print(self.name, "Ignoring task",t.name, t.id,t.ready())
             if self.debug:                          #pragma:nocover
-                print self.name, "FINAL QUEUE  ",queued
-                print self.name, "FINAL WAITING",waiting.keys()
-                print self.name, '---------------'
-                print self.name, "    LOOP"
-                print self.name, '---------------'
+                print(self.name, "FINAL QUEUE  ",queued)
+                print(self.name, "FINAL WAITING",waiting.keys())
+                print(self.name, '---------------')
+                print(self.name, "    LOOP")
+                print(self.name, '---------------')
         if self.debug:                              #pragma:nocover
-            print self.name, '---------------'
+            print(self.name, '---------------')
 
     def __str__(self):
         return "\n".join(["Workflow %s:" % self.name]+self._dfs_([self._start_task.id], lambda t: str(t)))
@@ -243,7 +228,6 @@ class Workflow(Task):
         if touched is None:
             touched = set()
         ans=[]
-        #print "Z",indices
         for i in indices:
             if i in touched:
                 # With this design, this condition should never be triggered
@@ -251,19 +235,12 @@ class Workflow(Task):
                 # O(n^2)
                 continue        #pragma:nocover
             ok=True
-            #print "X",i
-            #print "Y all keys",self._tasks.keys()
-            #print "Y prev params",self._tasks[i].inputs.keys()
-            #print "Y next paramsids",self._tasks[i].outputs.keys()
-            #print "Y prev ids",self._tasks[i].prev_task_ids()
-            #print "Y next ids",self._tasks[i].next_task_ids()
             task = self._tasks[i]
             for j in task.prev_task_ids():
                 if j is NoTask.id or j in touched:
                     continue
                 ok=False
                 break
-            #print "X",ok
             if not ok:
                 continue
             tmp = fn(task)
